==> gparted-0.2.5.tar.bz2: gparted-0.2.5/include/ext3.h <==
/* Copyright (C) 2004 Bart
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
 
#ifndef DEFINE_EXT3
#define DEFINE_EXT3

#include "../include/FileSystem.h"

namespace GParted
{

class ext3 : public FileSystem
{
public:
	FS get_filesystem_support( ) ;
	void Set_Used_Sectors( Partition & partition ) ;
	bool Create( const Partition & new_partition, std::vector<OperationDetails> & operation_details ) ;
	bool Resize( const Partition & partition_new,
		     std::vector<OperationDetails> & operation_details,
		     bool fill_partition = false ) ;
	bool Copy( const Glib::ustring & src_part_path,
		   const Glib::ustring & dest_part_path,
		   std::vector<OperationDetails> & operation_details ) ;
	bool Check_Repair( const Partition & partition, std::vector<OperationDetails> & operation_details ) ;
};


} //GParted

#endif //EXT3

==> gparted_0.5.1.orig.tar.bz2: gparted-0.5.1/include/ext3.h <==
/* Copyright (C) 2004 Bart
 * Copyright (C) 2008 Curtis Gedak
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
 
#ifndef DEFINE_EXT3
#define DEFINE_EXT3

#include "../include/FileSystem.h"

namespace GParted
{

class ext3 : public FileSystem
{
public:
	FS get_filesystem_support() ;
	void set_used_sectors( Partition & partition ) ;
	void read_label( Partition & partition ) ;
	bool write_label( const Partition & partition, OperationDetail & operationdetail ) ;
	bool create( const Partition & new_partition, OperationDetail & operationdetail ) ;
	bool resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition = false ) ;
	bool copy( const Glib::ustring & src_part_path,
		   const Glib::ustring & dest_part_path,
		   OperationDetail & operationdetail ) ;
	bool check_repair( const Partition & partition, OperationDetail & operationdetail ) ;
};


} //GParted

#endif //EXT3
